.. image:: https://badge.fury.io/py/branca.png
   :target: http://badge.fury.io/py/branca
.. image:: https://api.travis-ci.org/python-visualization/branca.png?branch=master
   :target: https://travis-ci.org/python-visualization/branca
.. image:: https://badges.gitter.im/Join%20Chat.svg
   :target: https://gitter.im/python-visualization/folium?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

Branca
======

This library is a spinoff from `folium`_, that would host the non-map-specific features.

It may become a HTML+JS generation library in the future.

It is based on Jinja2 only.

There's no documentation, but you can browse the `examples`_ gallery.

.. _`examples`: http://nbviewer.jupyter.org/github/python-visualization/branca/tree/master/examples
.. _`folium`: https://github.com/python-visualization/folium
